#include <algorithm>
#include <bitset>
#include <cassert>
#include <chrono>
#include <climits>
#include <cstdint>
#include <cstdio>
#include <cstdlib>
#include <cstring>
#include <ctime>
#include <deque>
#include <fstream>
#include <functional>
#include <iostream>
#include <iomanip>
#include <map>
#include <numeric>
#include <queue>
#include <random>
#include <set>
#include <stack>
#include <sstream>
#include <tuple>
#include <vector>

using namespace std;
using namespace chrono;

#ifdef DEBUG
	#define LOCAL_INPUT_FILE
#else
	//~ #define USE_FILE_IO
#endif

#ifdef USE_FILE_IO
	#define INPUT_FILE "input.txt"
	#define OUTPUT_FILE "output.txt"
	#define cin ____cin
	#define cout ____cout
	ifstream cin(INPUT_FILE);
	ofstream cout(OUTPUT_FILE);
#else
	#ifdef LOCAL_INPUT_FILE
		#define cin ____cin
		ifstream cin("input.txt");
	#endif
#endif

const int infinity = (int)1e9 + 42;
const int64_t llInfinity = (int64_t)1e18 + 256;
const int module = (int)1e9 + 7; 
const long double eps = 1e-8;

mt19937_64 randGen(system_clock().now().time_since_epoch().count());

inline void raiseError(string errorCode) {
	cerr << "Error : " << errorCode << endl;
	exit(42);
}

int TYPE_OPEN = 0;
int TYPE_ASK = 1;
int TYPE_CLOSE = 2;

struct Event {
	int type, time;
	int l, r;
	int tag;
	
	auto toPair() const {
		return make_pair(time, type);
	}
	
	inline friend bool operator<(const Event &a, const Event &b) {
		return a.toPair() < b.toPair();
	}
};

struct Node {
	int l, r, k;
	int mn, mx, sz;
};

class FenwickTree {
private:
	int n;
	vector<int64_t> a;
public:
	inline void add(int v, int64_t delta) {
		for (; v < n; v |= v+1) {
			a[v] += delta;
		}
	}
	
	inline int64_t sum(int v) {
		int64_t res = 0;
		for (; v >= 0; v &= v+1, v--) {
			res += a[v];
		}
		return res;
	}
	
	FenwickTree(int n)
		: n(n), a(n, 0) {
	}
};

signed main() {
	#ifndef USE_FILE_IO
		ios_base::sync_with_stdio(false);
	#endif
	
	vector<Event> evt;
	
	auto add = [&](int xl, int xr, int yl, int yr, int amount) {
		if (xl > xr || yl > yr) {
			return;
		}
		evt.push_back({TYPE_OPEN, xl, yl, yr+1, amount});
		evt.push_back({TYPE_CLOSE, xr, yl, yr+1, amount});
	};
	
	auto qry = [&](int x, int y, int pos) {
		evt.push_back({TYPE_ASK, x, y, y, pos});
	};
	
	int n; cin >> n;
	int tmn = -infinity, tmx = infinity;
	vector<Node> tree(n);
	for (Node &node : tree) {
		cin >> node.l >> node.r >> node.k;
		--node.l; --node.r;
	}
	
	function<void(int)> dfs = [&](int v) {
		Node &node = tree[v];
		node.sz = 1;
		node.mn = node.mx = node.k;
		if (node.l >= 0) {
			dfs(node.l);
			node.mn = min(node.mn, tree[node.l].mn);
			node.sz += tree[node.l].sz;
		}
		if (node.r >= 0) {
			dfs(node.r);
			node.mx = max(node.mx, tree[node.r].mx);
			node.sz += tree[node.r].sz;
		}
		if (node.l >= 0) {
			Node &left = tree[node.l];
			assert(left.mx < node.k);
			int lp = node.mn, rp = node.mx, rv = left.mx;
			//~ cout << "do : " << node.l+1 << endl;
			add(tmn, lp, rv, rp-1, -left.sz);
			add(rv+1, rp, tmn, tmx, -left.sz);
		}
		if (node.r >= 0) {
			Node &right = tree[node.r];
			assert(right.mx > node.k);
			int lp = node.mn, lv = right.mn, rp = node.mx;
			//~ cout << "do : " << node.r+1 << endl;
			add(lp+1, lv, rp, tmx, -right.sz);
			add(tmn, tmx, lp, lv-1, -right.sz);
		}
	};
	dfs(0);
	{
		Node &root = tree[0];
		//~ cout << "do : " << 1 << endl;
		add(tmn, root.mn, root.mx, tmx, -root.sz);
		add(tmn, tmx, tmn, root.mn - 1, -root.sz);
		add(root.mx + 1, tmx, tmn, tmx, -root.sz);
	}
	
	int q; cin >> q;
	vector<int> ans(q, n);
	for (int i = 0; i < q; ++i) {
		int l, r; cin >> l >> r;
		qry(l, r, i);
	}
	
	sort(evt.begin(), evt.end());
	map<int, int> compr;
	for (const Event &e : evt) {
		compr[e.l] = compr[e.r] = 42;
	}
	int cid = 0;
	for (auto &it : compr) {
		it.second = cid++;
	}
	for (Event &e : evt) {
		e.l = compr[e.l];
		e.r = compr[e.r];
	}
	
	FenwickTree fen(cid);
	for (const Event &e : evt) {
		if (e.type == TYPE_OPEN || e.type == TYPE_CLOSE) {
			int add = (e.type == TYPE_OPEN) ? +1 : -1;
			fen.add(e.l, add*e.tag);
			fen.add(e.r, -add*e.tag);
			continue;
		}
		if (e.type == TYPE_ASK) {
			ans[e.tag] += fen.sum(e.l);
			continue;
		}
		assert(false);
	}
	
	for (int i = 0; i < q; ++i) {
		cout << 2*ans[i] + 1 << "\n";
	}
	
	return 0;
}
