#define _CRT_SECURE_NO_WARNINGS
#include <iostream>
#include <vector>
#include <set>
#include <map>
#include <queue>
#include <string>
#include <algorithm>
#include <time.h>
#include <chrono>
#include <random>
#include <functional>
//#include <math.h>
#include <cmath>
#include <fstream>
#include <deque>
#include <unordered_map>
#include <unordered_set>
#include <stdlib.h>
#include <cstring>
#include <iomanip>
#include <cstdio>
#include <cassert>
#include <bitset>

#pragma comment(linker, "/STACK:36777216")
using namespace std;

typedef long long ll;

const int INFi = 1.5e9;
const ll INFll = 1e18;

using ld = double;

double eps = 1e-9;
const ld pi = acos(-1);


const int maxn = 2e5+65;

struct None {
    friend bool operator<(const None& lhs, const None& rhs) {
        return false;
    }
};

struct Edge {
    int to;
};

struct WEdge {
    int to;
    ll w;
};

#define ParEdgeType typename conditional<is_same<EIdType,None>::value, EType, pair<EIdType, EType>>::type
template<typename EIdType, typename EType>
struct PFInfo {
    int par = -1;
    ll dist = INFll;
    ParEdgeType parEdge;

    friend bool operator<(const PFInfo& a, const PFInfo& b) {
        return a.dist<b.dist;
    }

    bool isPath() {
        return dist!=INFll;
    }
};

#define FOR_GRAPH(ReturnType) template<typename EIdType_=EIdType> \
        typename enable_if<is_same<EIdType_, None>::value, ReturnType>::type
#define FOR_BOR(ReturnType) template<typename EIdType_=EIdType> \
        typename enable_if<!is_same<EIdType_, None>::value, ReturnType>::type

template<typename VType_, typename EType_, typename VIdType=None, typename EIdType=None>
struct Graph {
    using VType = VType_;
    using EType = EType_;
    vector<VType> v;
    typename conditional<is_same<EIdType, None>::value, vector<vector<EType>>, vector<map<EIdType, EType>>>::type g;
    vector<PFInfo<EIdType, EType>> pf;

    Graph(int n): v(n), g(n), pf(n) {};
    Graph(): Graph(0) {};

    FOR_GRAPH(void) addOEdge(int u, int v, const EType& newE) {g[u].push_back(newE); g[u].back().to = v;}
    FOR_BOR(void) addOEdge(int u, int v, const EType& newE) {assert(false);}
    FOR_GRAPH(void) addEdge(int u, int v, const EType& newE) {addOEdge(u,v, newE);addOEdge(v,u, newE);}
    FOR_BOR(void) addEdge(int u, int v, const EType& newE) {assert(false);}

    FOR_BOR(void) addOEdge(int u, int v, const EIdType& newEId, const EType& newE) {assert(g[u].count(newEId)==0); g[u][newEId] = newE; g[u][newEId].to = v;}
    FOR_GRAPH(void) addOEdge(int u, int v, const EIdType& newEId, const EType& newE) {assert(false);}

    //to update edge after insertion
    FOR_GRAPH(int) addOEdge(int u, int v) {g[u].emplace_back(); g[u].back().to = v; return ((int) g[u].size())-1;};
    FOR_BOR(int) addOEdge(int u, int v) {assert(false);};

    FOR_BOR(int) goTo(int from, const EIdType& eId, const EType& newE) {
        if (!g[from].count(eId)) {
            int to = g.addV();
            addOEdge(from, to, eId, newE);
        }
        return g[from][eId].to;
    }
    FOR_GRAPH(int) goTo(int from, const EIdType& eId, const EType& newE) {assert(false);}

    int addV() {
        int id = v.size();
        v.emplace_back();
        g.emplace_back();
        pf.emplace_back();
        return id;
    }

    map<VIdType, int> ids; //or unordered_map if better
    vector<VIdType> idsBack;

    //if too slow, use external vertex id generator, but don't forget to allocate graph of required size
    int asV(const VIdType& id) {
        if (!ids.count(id)) {
            ids[id] = addV();
            idsBack.push_back(id);
        }
        return ids[id];
    }
    const VIdType& asLabel(int id) {
        return idsBack[id];
    }

    void printAdj() const {
        for (int i=0;i<g.size();i++) {
            cout << i+1 << ": ";
            for (auto& it: g[i]) {
                cout << it.to+1 << " ";
            }
            cout << "\n";
        }
        cout << endl;
    }
};

template <typename T_>
struct RMQ {
    using T = T_;
    using PushT = None;
    vector<T> mas;
    T neutral;
    int size;
    std::function<T(const T&,const T&)> op;

    RMQ(int size, std::function<T(const T&,const T&)> op, T neutral) {
        this->neutral = neutral;
        int deg2 = 1;
        while (deg2<size) {
            deg2<<=1;
        }
        this->size = deg2;

        this->op = op;
        mas.assign(2*this->size, neutral);
    }

    void setVal(int ind, T val) {modify(ind,val);};//for compatibility for HLD
    T getVal(int ind) {
        return query(ind, ind);
    }
    void modify(int ind, T val) {
        ind += this->size;
        mas[ind] = val;
        for (ind >>= 1; ind >0 ;ind>>=1) mas[ind] = this->op(mas[ind << 1], mas[(ind<<1)+1]);
    }

    T query(int l, int r) {
        if (l>r) return this->neutral;
        l+=size; r+=size;
        T ans;
        if (l==r) {
            ans = mas[l];
        } else {
            ans = this->op(mas[l], mas[r]);
        }
        for (; l<r; l>>=1, r>>=1) {
            if ((l & 1) == 0 && (l + 1) < r) ans = this->op(ans, mas[l + 1]);
            if ((r & 1) == 1 && (r - 1) > l) ans = this->op(ans, mas[r - 1]);
        }
        return ans;
    }

};

template<typename GraphType, typename RMQType, bool ValuesInVerts = true>
struct HLD {
    using VType = typename GraphType::VType;
    using EType = typename GraphType::EType;
    using ValType = typename RMQType::T;
    using PushType = typename RMQType::PushT;

    vector<int> par, sz_sub, mx, pos, root, depth;
    vector<ValType> vals;
    RMQType& rmq;
    GraphType& g;
    std::function<ValType(const VType& v, const EType& e)> getValue;

    HLD(GraphType& g, RMQType& rmq, vector<int> roots,
        std::function<ValType(const VType& v, const EType& e)> getValue): g(g), rmq(rmq), getValue(getValue) {
        int n = g.v.size();

        par.assign(n, -1);
        sz_sub.assign(n, 0);
        mx.assign(n, -1);
        pos.assign(n, 0);
        root.assign(n, 0);
        depth.assign(n, 0);
        vals.resize(n);

        for (auto& v0: roots) {
            vals[v0] = getValue(g.v[v0], {});
            dfs_all(v0);
        }

        build_array();
    }

    void dfs_all(int v, int d = 0) {
        depth[v] = d;
        sz_sub[v] = 1;
        int ind = -1, mai = -1;
        for (auto it : g.g[v]) {
            if (it.to==0) continue;
            if (par[v] != it.to) {
                par[it.to] = v;
                vals[it.to] = getValue(g.v[it.to], it);
                dfs_all(it.to, d+1);
                sz_sub[v] += sz_sub[it.to];
                if (sz_sub[it.to] > mai) {
                    mai = sz_sub[it.to];
                    ind = it.to;
                }
            }
        }

        mx[v] = ind;
    }

    void build_array() {
        int cpos = 0;
        int n = g.v.size();
        for (int i=0;i<n;i++) {
            if (par[i] == -1 || mx[par[i]]!=i)
                for (int v = i; v!= -1; v= mx[v]) {
                    rmq.setVal(cpos, vals[v]);
                    pos[v] = cpos++;
                    root[v] = i;
                }
        }
    }

    int lca(int u, int v) {
        while (root[u]!=root[v]) {
            if (depth[root[u]] < depth[root[v]])
                swap(u,v);
            u = par[root[u]];
            if (u==-1) return -1;
        }
        if (depth[u]<depth[v])
            swap(u,v);
        return v;
    }

    ValType query(int u, int v) {
        auto ans = rmq.neutral;
        while (root[u]!=root[v]) {
            if (depth[root[u]] < depth[root[v]])
                swap(u,v);
            ans = rmq.op(ans, rmq.query(pos[root[u]], pos[u]));
            u = par[root[u]];
        }
        if (depth[u]<depth[v])
            swap(u,v);
        ans = rmq.op(ans, rmq.query(pos[v] + !ValuesInVerts, pos[u]));
        return ans;
    }

    void setVal(int v, ValType val) {
        rmq.setVal(pos[v], val);
    }

    ValType getVal(int v) {
        return rmq.getVal(pos[v]);
    }

    void modify(int u, int v, PushType val) { //group ops only
        while (root[u]!=root[v]) {
            if (depth[root[u]] < depth[root[v]])
                swap(u,v);
            rmq.modify(pos[root[u]], pos[u], val);
            u = par[root[u]];
        }
        if (depth[u]<depth[v])
            swap(u,v);
        rmq.modify(pos[v] + !ValuesInVerts, pos[u], val);
    }
};

int parLeft[maxn], parRight[maxn];
int par[maxn];
int isLeftChild[maxn], isRightChild[maxn];
int isLeaf[maxn];
int lefts[maxn],rights[maxn];
void solve() {
    int n;
    cin >> n;
    Graph<None, Edge> g(n+1);
    map<int, int> keyToV;
    par[1] = 1;
    parLeft[1] = parRight[1] = 1;
    for (int i=1;i<=n;i++) {
        int li,ri,ki;
        cin >> li >> ri >> ki;
        keyToV[ki] = i;
        lefts[i] = li;
        rights[i] = ri;
        if (li!=0) {
            isLeftChild[li] = 1;
            g.addOEdge(i, li);
            parLeft[li] = parLeft[i];
            parRight[li] = li;
            par[li] = i;
        }
        if (ri!=0) {
            isRightChild[ri] = 1;
            g.addOEdge(i, ri);
            parRight[ri] = parRight[i];
            parLeft[ri] = ri;
            par[ri] = i;
        }
        isLeaf[i] = li==0 && ri==0;
    }

    RMQ<int> rmqL(n+1, [](const int& a, const int& b) {return a+b;}, 0);
    HLD<decltype(g), decltype(rmqL)> hldL(g, rmqL, {1}, [](const auto& v, const auto& e) {return /*isLeftChild[e.to];*/1;});

    RMQ<int> rmqR(n+1, [](const int& a, const int& b) {return a+b;}, 0);
    HLD<decltype(g), decltype(rmqR)> hldR(g, rmqR, {1}, [](const auto& v, const auto& e) {return /*isRightChild[e.to];*/1;});



    int q;
    cin >> q;
    for (int i=0;i<q;i++) {
        int li,ri;
        cin >> li >> ri;
        auto upperLi = keyToV.lower_bound(li);
        auto lowerRi = keyToV.upper_bound(ri);

        if (upperLi == keyToV.end()) {
            cout << 1 << "\n";
            continue;
        }
        if (lowerRi == keyToV.begin()) {
            cout << 1 << "\n";
            continue;
        }
        lowerRi--;

        auto it = lowerRi;
        it++;
        if (it==upperLi) {
            cout << 1 << "\n";
            continue;
        }

        int leftV = upperLi->second;
        int rightV = lowerRi->second;

//TODO: upperLi>lowerRi
        int lca = hldL.lca(leftV, rightV);
        int ans = 0;
        if (isLeaf[leftV]) {
            leftV = parLeft[leftV];
        } else {
            if (lefts[leftV] != 0) {
                if (leftV==lca) {
                    ans+=1;
                } else {
                    ans+=2;
                }

            }
        }
        if (isLeaf[rightV]) {
            rightV = parRight[rightV];
        } else {
            if (rights[rightV] != 0) {
                if (leftV==lca) {
                    ans+=1;
                } else {
                    ans+=2;
                }
            }
        }
        int vertsL = hldL.query(leftV, lca) - 1;
        int vertsR = hldR.query(rightV, lca) - 1;
        ans += vertsL;
        ans += max(vertsL-1,0);
        ans += vertsR;
        ans += max(vertsR-1,0);
        ans++;
        cout << ans << "\n";

    }

}



int main() {
    ios_base::sync_with_stdio(false);
    cin.tie(0);
    cout.tie(0);
   // freopen("input.txt","r",stdin);
    //freopen("output.txt","w",stdout);
    cout << setprecision(15) << fixed;
    //int t;
    //cin >> t;
    //for (int i=0;i<t;i++)
    solve();
    return 0;
}