#include <bits/stdc++.h>

using namespace std;

using ll = long long;
using ull = unsigned long long;

mt19937 mt(736);

namespace std
{
	template<>
	struct hash<pair<int, int>>
	{
		std::size_t operator()(const pair<int, int> &s) const noexcept
		{
			return std::hash<ll>{}(s.first * ll(1ull << 32u) + s.second);
		}
	};
}

const array<pair<int, int>, 6> moves = {pair{1, 0}, {0, 1}, {-1, 1}, {-1, 0}, {0, -1}, {1, -1}};

class game
{
	int n, cnt;
	istream &cin;
	ostream &cout;
	unordered_set<pair<int, int>> dead;
	pair<int, int> we, enemy;

	bool check_bad(const pair<int, int> &q)
	{
		for (int i = 0; i < moves.size(); i++)
			if (!is_dead(try_move(q, i)))
				return false;
		return true;
	}

	bool is_dead(int x, int y) const
	{
		if (x < -n || y < -n || x > n || y > n)
			return true;
		if (x + y < -n || x + y > n)
			return true;
		return dead.count({x, y});
	}

	bool is_dead(const pair<int, int> &q) const
	{
		return is_dead(q.first, q.second);
	}

	bool check_move(int d) const
	{
		return !is_dead(try_move(we, d));
	}

	static pair<int, int> try_move(pair<int, int> q, int d)
	{
		return {q.first + moves.at(d).first, q.second + moves.at(d).second};
	}

	void move(int d)
	{
		cnt++;

		assert(!is_dead(try_move(we, d)));

		cout << moves[d].first << ' ' << moves[d].second << endl << flush;
		we = try_move(we, d);
		dead.insert(we);

		string line;

#ifdef LOCAL
		vector<int> pos;

		for (int i = 0; i < moves.size(); i++)
			if (!is_dead(try_move(enemy, i)))
				pos.push_back(i);

		shuffle(pos.begin(), pos.end(), mt);

		if (pos.empty())
			line = "win";
		else
			line = "move " + to_string(moves[pos.front()].first) + " " + to_string(moves[pos.front()].second);

		cout << line << endl;
#else
		cin >> line;

		if (line == "move")
		{
			int x, y;

			cin >> x >> y;

			line += " " + to_string(x);
			line += " " + to_string(y);
		}
#endif

		stringstream ss(line);

		string str;

		ss >> str;

		assert(str == "move" || str == "win");

		if (str == "move")
		{
			int dx, dy;

			ss >> dx >> dy;

			enemy.first += dx;
			enemy.second += dy;
			dead.insert(enemy);
		}
		else
			throw runtime_error("we won");

#ifdef LOCAL
		cout << "we" << endl;
		cout << we.first << ' ' << we.second << endl;
		cout << "enemy" << endl;
		cout << enemy.first << ' ' << enemy.second << endl;
#endif
	}


	int bfs(const pair<int, int> &from, const unordered_set<pair<int, int>> &to) const
	{
		unordered_set<pair<int, int>> used;
		queue<pair<pair<int, int>, int>> q;
		q.emplace(from, 0);

		while (!q.empty() && !to.count(q.front().first))
		{
			pair<int, int> v;
			int d;

			tie(v, d) = q.front();
			q.pop();

			if (!used.count(v) && (v == from || !is_dead(v)))
			{
				used.insert(v);

				for (int i = 0; i < moves.size(); i++)
					q.emplace(try_move(v, i), d + 1);
			}
		}

		return q.empty() ? 100500 : q.front().second;
	}


	void go_to(const function<int(pair<int, int>)> &fn)
	{
		int best = -1, val = numeric_limits<int>::max();

		for (int i = 0; i < moves.size(); i++)
			if (check_move(i))
			{
				auto t = fn(try_move(we, i));

				if (best == -1 || t < val)
				{
					best = i;
					val = t;
				}
			}

		if (best == -1)
			cerr << "we lose after move " << cnt << endl;

		assert(best != -1);

		move(best);
	}


	void go_to(const unordered_set<pair<int, int>> &q)
	{
		go_to([&](const pair<int, int> &v)
		      {
			      return bfs(v, q);
		      });
	}


public:
	game(int n, istream &cin, ostream &cout) : n(n), cnt(0), cin(cin), cout(cout), we(-n / 2, 0), enemy(n / 2, 0)
	{
		dead.insert(we);
		dead.insert(enemy);
	}

	void operator()()
	{
		while (bfs(we, {{0, 0}}) > 0)
			go_to({{0, 0}});

		vector<unordered_set<pair<int, int>>> dest(2);

		for (int i = -n; i <= 0; i++)
			dest[0].emplace(i, n);
		for (int i = 0; i <= n; i++)
			dest[1].emplace(i, -n);

		if (enemy.second < 0)
			dest[0].swap(dest[1]);

		for (const auto &it : dest)
		{
			while (bfs(we, it) > 1 && bfs(we, it) < 100500)
				go_to(it);
			go_to({{-n, 0}});
		}

#ifdef LOCAL
		cout << "in loop after move " << cnt << endl;
#endif

		while (true)
			go_to([&](const pair<int, int> &q)
			      {
				      if (check_bad(q))
					      return 100500;
				      return -(abs(q.first) + abs(q.second));
			      });
	}
};


void solve(istream &cin = std::cin, ostream &cout = std::cout)
{
	int t, n;

	cin >> t >> n;

	for (int i = 0; i < t; i++)
	{
		try
		{
			game{n, cin, cout}();
		}
		catch (...)
		{}
	}
}


int main()
{
	cout << fixed;

#ifdef LOCAL
	auto st = clock();

	ifstream fin("../input.txt");

	do
	{
		solve(fin);

		cout << "===" << endl;

		string str;
		while (getline(fin, str) && str != string(max(1, (int) str.size()), '='));
	} while (fin);

	cout << setprecision(6) << "clock: " << double(clock() - st) / CLOCKS_PER_SEC << endl;
#else
	solve();
#endif

	return 0;
}
