#ifdef LOCAL
#define _GLIBCXX_DEBUG
#endif

#include <bits/stdc++.h>

using namespace std;

using ll = long long;
using ull = unsigned long long;

using ld = long double;

mt19937_64 mt(736736);

const ld inf = ld(1e100);

void floyd(vector<vector<ld>> &dist)
{
	const int n = int(dist.size());

	for (int k = 0; k < n; k++)
		for (int i = 0; i < n; i++)
			for (int j = 0; j < n; j++)
				dist[i][j] = min(dist[i][j], dist[i][k] + dist[k][j]);
}

struct point
{
	int x, y;
};

template<class T>
void remin(T &x, const T &y)
{
	x = min(x, y);
}

struct frac
{
	ll p, q;

	explicit frac(const ll p_ = 0, const ll q_ = 1) : p(p_), q(q_)
	{}

	frac operator+(const frac &o) const
	{
		return frac(p * o.q + o.p * q, q * o.q);
	}

	frac operator-(const frac &o) const
	{
		return frac(p * o.q - o.p * q, q * o.q);
	}

	frac operator*(const frac &o) const
	{
		return frac(p * o.p, q * o.q);
	}

	frac operator/(const frac &o) const
	{
		return frac(p * o.q, o.p * q);
	}

	bool operator<(const frac &o) const
	{
		return p * o.q < o.p * q;
	}

	bool operator>(const frac &o) const
	{
		return p * o.q < o.p * q;
	}

	bool operator<=(const frac &o) const
	{
		return p * o.q <= o.p * q;
	}

	bool operator>=(const frac &o) const
	{
		return p * o.q <= o.p * q;
	}

	frac sqr() const
	{
		return *this * *this;
	}
};

const ld inf = 1e100;

/// (0, y1) -> (seg_len, y2)
ld min_dist(const ll y1, const ll y2, const ll x, const frac l, const frac r, const ll jump)
{
	assert(l <= r);
	assert(y1 > 0 && y2 > 0);

	auto check = [&](const frac &pt)
	{
		if (pt < l)
			return inf;
		if (pt > r)
			return inf;
		if (pt * pt + frac(y1 * y1) > frac(jump_len * jump_len))
			return inf;
		if ((frac(x) - pt).sqr() + frac(y2 * y2) > frac(jump_len * jump_len))
			return inf;

		const ld pt_ld = pt.as_ld();
		return sqrtl(y1 * y1 + pt_ld * pt_ld) + sqrtl(y2 * y2 + (x - pt_ld) * (x - pt_ld));
	};

	ld ans = inf;
	ans = min(ans, check(l));
	ans = min(ans, check(r));
	ans = min(ans, check(frac(x * x + y1 * y1 + y2 * y2, 2 * x));
	ans = min(ans, check(frac(y1 * x, y1 + y2)));
	return ans;
}

void solve(istream &cin = std::cin, ostream &cout = std::cout)
{
	int n, len;
	cin >> n >> len;

	vector<int> d(n), h(n);
	for (auto &it : d)
		cin >> it;
	for (auto &it : h)
		cin >> it;

	vector<point> pts;
	for (int i = 0; i < n; i++)
	{
		pts.push_back(point{i == 0 ? 0 : d[i - 1], h[i]});
		pts.push_back(point{d[i], h[i]});
	}

	vector<vector<ld>> dist(2 * n, vector<ld>(2 * n, inf));
	auto add_edge = [&](const int l, const int r, const ld &cur_dist)
	{
		remin(dist[l][r], cur_dist);
		remin(dist[r][l], cur_dist);
	};

	for (int i = 0; i < n; i++)
	{
		assert(pts[2 * i].y == pts[2 * i + 1].y);
		add_edge(2 * i, 2 * i + 1, abs(pts[2 * i].x - pts[2 * i + 1].x));

		if (i + 1 < n)
		{
			assert(pts[2 * i + 1].x == pts[2 * i + 2].x);
			const int d = abs(pts[2 * i + 1].y - pts[2 * i + 2].y);
			if (d <= L)
				add_edge(2 * i + 1, 2 * i + 2, d);
		}
	}

	for (int i = 0; i < int(pts.size()); i++)
		for (int j = 0; j < n; j++)
			if (j != i / 2)
			{
				auto &cur = (j < i / 2 ? dist[i][2 * j] : dist[i][2 * j + 1]);

				const frac first_x = (j < i / 2 : get_last : get_first)(pts[i], j, pts);
				const frac start = frac(pts[2 * j].x), fin = frac(pts[2 * j + 1].x), cur_y = pts[2 * j].y;

				const ll dy = (pts[i].y - cur_y);
				const frac sq_len = (first_x - (j < i / 2 ? start : fin)).sqr() + frac(dy).sqr();
				if (sq_len <= frac(len * len))
				{
					const ll extreme = ll(dx) * dx + ll(dy * dy);
					if (extreme <= len * len)
						cur = min(cur, sqrtl(extreme));
					else
					{
						const ld remin_with = (pts[2 * j + 1].x - sqrtl(len * len - dy * dy) + len);
						cur = min(cur, remin_with);
					}
				}
			}

	for (int i = 0;)

	floyd(dist);

	cout << fixed << setprecision(numeric_limits<ld>::digits10);
	if (dist[0][2 * n - 1] != inf)
		cout << dist[0][2 * n - 1] << endl;
	else
		cout << -1 << endl;
}

int main()
{
	ios_base::sync_with_stdio(false);
	cin.tie(nullptr);

#ifdef LOCAL
	while (true)
	{
		stringstream test, out;
		gen(test);
		cerr << test.str() << endl;
		solve(test, out);
	}

	auto st = clock();

	ifstream fin("../input.txt");
	do
	{
		solve(fin);

		cout << "===" << endl;

		string str;
		while (getline(fin, str) && str != string(max(1, (int) str.size()), '='));
	} while (fin);

	cout << setprecision(6) << "clock: " << double(clock() - st) / CLOCKS_PER_SEC << endl;
#else
	solve();
#endif

	return 0;
}
