#include <bits/stdc++.h>

using namespace std;

typedef pair<int, int> pii;
typedef pair<long long, long long> pll;
typedef long long ll;
typedef unsigned int ui;
typedef unsigned long long ull;
typedef long double ld;

const int inf = 1e9;
const ll inf64 = 1e18;

struct Fen {
    int n = 0;
    vector<int> f;
    vector<int> crd;

    Fen(vector<int> a) {
        crd = a;
        sort(crd.begin(), crd.end());
        crd.erase(unique(crd.begin(), crd.end()), crd.end());
        n = (int) crd.size();
        f.resize(n);
    }

    void add(int x) {
        int pos = lower_bound(crd.begin(), crd.end(), x) - crd.begin();
        pos = n - 1 - pos;
        for (int cur = pos; cur < n; cur |= (cur + 1))
            f[cur]++;
    }

    int get(int x) {
        int pos = lower_bound(crd.begin(), crd.end(), x) - crd.begin();
        pos = n - 1 - pos;
        int res = 0;
        for (int cur = pos; cur >= 0; cur = (cur & (cur + 1)) - 1)
            res += f[cur];
        return res;
    }
};

struct Node {
    int l = 0;
    int r = 0;
    int x = 0;
};

struct Query {
    int l = 0;
    int r = 0;
    int id = 0;
};

void gen(int& n, vector<Node>& nodes, int& q, vector<Query>& queries, mt19937& rnd) {
    const int MAXN = 50;
    const int MAXX = 50;
    n = rnd() % MAXN + 1;
    nodes.resize(n + 1);
    vector<int> order;
    set<int> values;
    for (int i = 0; i < n; i++) {
        while (1) {
            int x = rnd() % (2 * MAXX + 1) - MAXX;
            if (values.count(x))
                continue;
            values.insert(x);
            order.push_back(x);
            break;
        }
    }
    sort(order.begin(), order.end());
    int cur = 1;
    function<int(int, int)> build = [&](int l, int r) -> int {
        if (l > r)
            return 0;
        int pos = rnd() % (r - l + 1) + l;
        int v = cur++;
        int lv = build(l, pos - 1);
        int rv = build(pos + 1, r);
        nodes[v].x = order[pos];
        nodes[v].l = lv;
        nodes[v].r = rv;
        return v;
    };
    build(0, n - 1);
    q = rnd() % MAXN + 1;
    queries.resize(q);
    for (int i = 0; i < q; i++) {
        queries[i].l = rnd() % (2 * MAXX + 1) - MAXX;
        queries[i].r = rnd() % (2 * MAXX + 1) - MAXX;
        queries[i].id = i;
        if (queries[i].l > queries[i].r)
            swap(queries[i].l, queries[i].r);
    }
}

void read(int& n, vector<Node>& nodes, int& q, vector<Query>& queries) {
    cin >> n;
    nodes.resize(n + 1);
    for (int i = 1; i <= n; i++) {
        cin >> nodes[i].l;
        cin >> nodes[i].r;
        cin >> nodes[i].x;
    }
    cin >> q;
    queries.resize(q);
    for (int i = 0; i < q; i++) {
        cin >> queries[i].l;
        cin >> queries[i].r;
        queries[i].id = i;
    }
}

vector<int> fast(int n, vector<Node> nodes, int q, vector<Query> queries) {
    vector<int> mn(n + 1, inf), mx(n + 1, -inf);
    function<void(int)> dfs = [&](int v) {
        if (v == 0)
            return;
        mn[v] = mx[v] = nodes[v].x;
        for (int son : {nodes[v].l, nodes[v].r}) {
            if (son > 0) {
                dfs(son);
                mn[v] = min(mn[v], mn[son]);
                mx[v] = max(mx[v], mx[son]);
            }
        }
    };
    dfs(1);
    vector<int> rs, ls;
    vector<pii> segs;
    for (int v = 1; v <= n; v++) {
        rs.push_back(mx[v]);
        ls.push_back(mn[v]);
        segs.emplace_back(mx[v], mn[v]);
    }
    sort(rs.begin(), rs.end());
    sort(ls.begin(), ls.end());
    vector<int> res(q);
    sort(queries.begin(), queries.end(), [&](const Query& q1, const Query& q2) {
        return q1.r < q2.r;
    });
    sort(segs.begin(), segs.end());
    Fen fen(ls);
    for (int i = 0, it = 0; it < q; it++) {
        const auto& query = queries[it];
        while (i < (int) segs.size() && segs[i].first <= query.r) {
            // add
            fen.add(segs[i].second);
            i++;
        }
//        for (int j = 0; j < i; j++) {
//            if (segs[j].second >= query.l)
//                res[query.id]++;
//        }
        res[query.id] += fen.get(query.l);
        res[query.id] += ls.end() - upper_bound(ls.begin(), ls.end(), query.r);
        res[query.id] += lower_bound(rs.begin(), rs.end(), query.l) - rs.begin();
    }
    for (int i = 0; i < q; i++) {
        res[i] = n - res[i];
        res[i] = 2 * res[i] + 1;
    }
    return res;
}

vector<int> slow(int n, vector<Node> nodes, int q, vector<Query> queries) {
    vector<int> res(q);
    vector<int> mn(n + 1, inf), mx(n + 1, -inf);
    function<void(int)> go = [&](int v) {
        if (v == 0)
            return;
        mn[v] = mx[v] = nodes[v].x;
        for (int son : {nodes[v].l, nodes[v].r}) {
            if (son > 0) {
                go(son);
                mn[v] = min(mn[v], mn[son]);
                mx[v] = max(mx[v], mx[son]);
            }
        }
    };
    go(1);
    function<void(int, int, int, int&)> dfs = [&](int v, int L, int R, int& acc) {
        if (v == 0)
            return;
        if (L <= mn[v] && mx[v] <= R)
            return;
        if (mx[v] < L || R < mn[v])
            return;
        acc += 2;
        dfs(nodes[v].l, L, R, acc);
        dfs(nodes[v].r, L, R, acc);
    };
    for (int i = 0; i < q; i++) {
        res[i] = 1;
        const auto& query = queries[i];
        dfs(1, query.l, query.r, res[i]);
    }
    return res;
}

void work() {
    int n, q;
    vector<Node> nodes;
    vector<Query> queries;
    read(n, nodes, q, queries);
    vector<int> fs = fast(n, nodes, q, queries);
    for (int x : fs)
        cout << x << "\n";
}

void test() {
    mt19937 rnd(42);
    while (1) {
        int n, q;
        vector<Node> nodes;
        vector<Query> queries;
        gen(n, nodes, q, queries, rnd);
        vector<int> fs = fast(n, nodes, q, queries);
        vector<int> sl = slow(n, nodes, q, queries);
        if (fs == sl) {
            cout << "OK" << endl;
        } else {
            cout << "WA\n";
            break;
        }
    }
}

int main() {

#ifdef DEBUG
    freopen("input.txt", "r", stdin);
#endif

    ios_base::sync_with_stdio(0);
    cin.tie(0);

    work();
//    test();

    return 0;
}
