#include <iostream>
#include <algorithm>
#include <vector>
#include <cstdio>
#include <cassert>
#include <cmath>

using namespace std;

const int MAXN = 2e6 + 100;
const int MOD = 1e9 + 7;
long long fac[MAXN];
long long inv_fac[MAXN];

vector <pair <double, double> > intersections;

pair <int, int> construct_point(int kek, int x) {
	return make_pair(x, x + kek);
}

bool check_in(pair <int, int> p, int ax, int ay, int bx, int by, int cx, int cy) {
	int px = p.first, py = p.second;
	long long v1 = (long long)(cx - ax) * (long long)(py - ay) - (long long)(cy - ay) * (long long)(px - ax);
	long long v2 = (long long)(ax - bx) * (long long)(py - by) - (long long)(ay - by) * (long long)(px - bx);
	long long v3 = (long long)(bx - cx) * (long long)(py - cy) - (long long)(by - cy) * (long long)(px - cx);
	if (v1 <= 0 && v2 <= 0 && v3 <= 0)
		return true;
	if (v1 >= 0 && v2 >= 0 && v3 >= 0)
		return true;
	return false;
}

void intersect(int kek, int ax, int ay, int bx, int by) {
	if (ax + kek == ay)
		return;
	if (bx + kek == by)
		return;
	if (ay - ax < kek && by - bx < kek)
		return;
	if (ay - ax > kek && by - bx > kek)
		return;
	int a = (by - ay), b = (ax - bx);
	int c = -ax * a - ay * b;
	double x = (double)(-c - b * kek) / (double)(a + b);
	double y = x + (double)kek;
	intersections.push_back({x, y});
}

long long pow_(long long a, long long b) {
	if (b == 0)
		return 1;
	long long p = pow_(a, b / 2);
	if (b % 2 == 0)
		return (p * p) % MOD;
	else
		return (((p * p) % MOD) * a) % MOD;
}

void precalc() {
	fac[0] = 1;
	inv_fac[0] = 1;
	for (int i = 1; i < MAXN; i++) {
		fac[i] = ((long long)i * fac[i - 1]) % MOD;
		inv_fac[i] = pow_(fac[i], MOD - 2);
	}
}

long long c(int n, int k) {
	return (((fac[n] * inv_fac[k]) % MOD) * inv_fac[n - k]) % MOD;
}

long long pref_sum_keks(int k, int n) {
	// c(k, k) + ... + c(n, k) = c(n+1, k+1)
	
	return c(n + 1, k + 1);
}

long long sum_keks(int k, int n1, int n2) {
	// c(n1, k) + ... + c(n2, k)
	if (n1 == k)
		return pref_sum_keks(k, n2);
	return pref_sum_keks(k, n2) - pref_sum_keks(k, n1 - 1);
}

int32_t main() {
	//assert(freopen("input.txt", "r", stdin));
	//assert(freopen("output.txt", "w", stdout));
	
	ios_base::sync_with_stdio(false);
	
	precalc();
	
	int t; cin >> t;
	for (int i = 0; i < t; i++) {
		int ax, ay, bx, by, cx, cy;
		cin >> ax >> ay >> bx >> by >> cx >> cy;
		
		long long res = 0;
		for (int kek = 0; kek <= 2e6; kek += 2) {
			intersections.clear();
			// intersect triangle with y = x + kek
			if (ax + kek == ay) {
				intersections.push_back({ax, ay});
			}
			if (bx + kek == by) {
				intersections.push_back({bx, by});
			}
			if (cx + kek == cy) {
				intersections.push_back({cx, cy});
			}
			intersect(kek, ax, ay, bx, by);
			intersect(kek, ax, ay, cx, cy);
			intersect(kek, bx, by, cx, cy);
			
			if (int(intersections.size()) == 0)
				continue;
			
			if (int(intersections.size()) == 1)
				intersections.push_back(intersections[0]);
			
			if (intersections[0].first > intersections[1].first)
				swap(intersections[0], intersections[1]);
			
			int x1 = ceil(intersections[0].first);
			if (check_in(construct_point(kek, x1 - 1), ax, ay, bx, by, cx, cy))
				x1--;
			int x2 = floor(intersections[1].first);
			if (check_in(construct_point(kek, x2 + 1), ax, ay, bx, by, cx, cy))
				x2++;
			x1 = max(x1, -kek / 2);
			
			if (x2 < x1)
				continue;
			
			int y1 = x1 + kek, y2 = x2 + kek;
			
			res = (res + sum_keks(kek / 2, y1, y2)) % MOD;
		}
		
		cout << res << endl;
	}
	
	return 0;
}
