import java.util.*;
import java.math.*;

public class Main {

    private static BigInteger gcd(BigInteger a, BigInteger b, IntRef x, IntRef y)
    {
        if(a.equals(BigInteger.ZERO))
        {
            x.value = BigInteger.ZERO;
            y.value = BigInteger.ONE;
            return b;
        }

        IntRef x1 = new IntRef();
        IntRef y1 = new IntRef();
        BigInteger d = gcd(b.mod(a), a, x1, y1);
        x.value = y1.value.subtract(b.divide(a).multiply(x1.value));
        y.value = x1.value;
        return d;
    }

    private static boolean find_any_solution(BigInteger a, BigInteger b, BigInteger c, IntRef x0, IntRef y0, IntRef g)
    {
        g.value = gcd(a.abs(), b.abs(), x0, y0);
        if(!c.mod(g.value).equals(BigInteger.ZERO))
            return false;

        x0.value = x0.value.multiply(c.divide(g.value));
        y0.value = y0.value.multiply(c.divide(g.value));
        if(a.signum() == -1) x0.value = x0.value.negate();
        if(b.signum() == -1) y0.value = y0.value.negate();
        return true;
    }

    private static void shift_solution(IntRef x, IntRef y, BigInteger a, BigInteger b, BigInteger cnt)
    {
        x.value = x.value.add(cnt.multiply(b));
        y.value = y.value.subtract(cnt.multiply(a));
    }

    private static BigInteger find_all_solutions(BigInteger a, BigInteger b, BigInteger c, BigInteger minx, BigInteger maxx, BigInteger miny, BigInteger maxy)
    {
        IntRef x = new IntRef();
        IntRef y = new IntRef();
        IntRef g = new IntRef();

        if(!find_any_solution(a, b, c, x, y, g))
            return BigInteger.ZERO;

        a = a.divide(g.value);
        b = b.divide(g.value);

        int sign_a = a.signum();
        int sign_b = b.signum();

        shift_solution(x, y, a, b, minx.subtract(x.value).divide(b));
        if(x.value.compareTo(minx) < 0)
            shift_solution(x, y, a, b, BigInteger.valueOf(sign_b));
        if(x.value.compareTo(maxx) > 0)
            return BigInteger.ZERO;
        BigInteger lx1 = x.value;

        shift_solution(x, y, a, b, maxx.subtract(x.value).divide(b));
        if(x.value.compareTo(maxx) > 0)
            shift_solution(x, y, a, b, BigInteger.valueOf(-sign_b));
        BigInteger rx1 = x.value;

        shift_solution(x, y, a, b, y.value.subtract(miny).divide(a));
        if(y.value.compareTo(miny) < 0)
            shift_solution(x, y, a, b, BigInteger.valueOf(-sign_a));
        if(y.value.compareTo(maxy) > 0)
            return BigInteger.ZERO;
        BigInteger lx2 = x.value;

        shift_solution(x, y, a, b, y.value.subtract(maxy).divide(a));
        if(y.value.compareTo(maxy) > 0)
            shift_solution(x, y, a, b, BigInteger.valueOf(sign_a));
        BigInteger rx2 = x.value;

        if(lx2.compareTo(rx2) > 0)
        {
            BigInteger t = lx2;
            lx2 = rx2;
            rx2 = t;
        }

        BigInteger lx = lx1.max(lx2);
        BigInteger rx = rx1.min(rx2);

        return rx.subtract(lx).divide(b.abs()).add(BigInteger.ONE);
    }


    public static void main(String[] args) {
        Scanner s = new Scanner(System.in);

        final BigInteger lim = new BigInteger("1000000000000000007");

        int t = s.nextInt();
        while(t-- > 0)
        {
            BigInteger x = s.nextBigInteger();
            BigInteger y = s.nextBigInteger();

            System.out.println(find_all_solutions(x, y, x.multiply(x), BigInteger.ONE, lim, BigInteger.ONE, lim));
        }
    }
}

class IntRef
{
    public BigInteger value;
}

