#include <bits/stdc++.h>

using namespace std;

typedef long long ll;
typedef long double ld;

const int INF = 2e9;
const ll MOD = 1e9 + 7;
const ld EPS = 1e-9;
const int MAX = 2e6 + 10;
const int N = 1e6 + 10;

struct PtInt {
  ll x;
  ll y;

  PtInt operator - (const PtInt& a) const {
      return {x - a.x, y - a.y};
  }
};

struct Pt {
    ld x, y;
    Pt() {}
    Pt(ld x, ld y): x(x), y(y) {}

    Pt operator - (const Pt& a) const {
        return {x - a.x, y - a.y};
    }
    Pt operator + (const Pt& a) const {
        return {x + a.x, y + a.y};
    }
    Pt operator * (ld k) const {
        return {x * k, y * k};
    }
    Pt operator / (ld k) const {
        return {x / k, y / k};
    }
    bool operator < (const Pt& a) const {
      if (x != a.x) return x < a.x;
      return y < a.y;
    }
    void read() {
      cin >> x >> y;
    }
};

struct Line {
    ld a, b, c;
    Line() {}
    Line(ld a, ld b, ld c): a(a), b(b), c(c) {}

    Line(Pt p1, Pt p2) {
      a = p1.y - p2.y;
      b = p2.x - p1.x;
      c = p1.x * p2.y - p2.x * p1.y;
    }
};

Line get_ort_line(Pt a, Line l) {
    Line ans = Line(-l.b, l.a, 0);
    ans.c = -(ans.a * a.x + ans.b * a.y);
    return ans;
}

ld pt_line_dist(Pt p, Line l) {
  return abs(l.a * p.x + l.b * p.y + l.c) / sqrt(l.a * l.a + l.b * l.b);
}

ld pt_dist(Pt a, Pt b) {
  return hypotl(a.x - b.x, a.y - b.y);
}

bool is_pt_on_line(Pt p, Line l) {
  return pt_line_dist(p, l) < EPS;
}

ld cross_product(Pt a, Pt b) {
    return a.x * b.y - a.y * b.x;
}

ll cross_product(PtInt a, PtInt b) {
    return (ll)a.x * b.y - (ll)a.y * b.x;
}

ld dot_product(Pt a, Pt b) {
    return a.x * b.x + a.y * b.y;
}

Pt get_lines_intersect(Line a, Line b) {
    return Pt((a.b * b.c - a.c * b.b) / (a.a * b.b - a.b * b.a), (a.a * b.c - a.c * b.a) / (a.b * b.a - a.a * b.b));
}

ll cands[N];

bool pt_int_tr(ll x, ll y, const vector<PtInt>& t) {
  PtInt p = PtInt{x, y};
  bool ok = true;
  bool pos = false;
  bool neg = false;
  for (int i = 0; i < 3; ++i) {
    int j = (i + 1) % 3;
    auto p1 = t[j] - t[i];
    auto p2 = p - t[i]; 
    ll val = (cross_product(p1, p2));
    if (val > 0) pos = true;
    if (val < 0) neg = true;
  }
  if (pos && neg) return false;
  return true;
}

void clamp_mod(pair<ll, ll>& p, int mod) {
  while (abs(p.first) % 2 != mod) p.first++;
  while (abs(p.second) % 2 != mod) p.second--;
  if (p.first > p.second) {
    p = {INF, -INF};
  }
}

pair<ll, ll> get_borders(ll y, const vector<PtInt>& t, const vector<Line>& lines) {
  Line hor = Line(0, 1, -y); 
  ll min_y = INF, max_y = -INF;
  for (const auto& p: t) {
    min_y = min(min_y, (ll)round(p.y));
    max_y = max(max_y, (ll)round(p.y));
  }
  if (min_y > y || max_y < y) return {INF, -INF};
  vector<ld> x_inters;
  for (int i = 0; i < 3; ++i) {
    int j = (i + 1) % 3;
    if (t[i].y == y && t[j].y == y) {
      pair<ll, ll>ans = {max(-y, min(t[i].x, t[j].x)), min(y, max(t[i].x, t[j].x))}; 
      clamp_mod(ans, y % 2);
      return ans;
    } else if (t[i].y != t[j].y) {
      Line l = lines[i];
      auto inter = get_lines_intersect(l, hor); 
      x_inters.push_back(inter.x);
    }
  }

  int ptr = 0;
  for (auto x: x_inters) {
    int x_r = (ll)round(x);
    for (int d = -1; d <= 1; ++d) {
      cands[ptr++] = (x_r + d);
    }
  }

  sort(cands, cands + ptr);
  ptr = unique(cands, cands + ptr) - cands;
  ll min_x = INF;
  ll max_x = -INF;
  for (int i = 0; i < ptr; ++i) {
    ll x = cands[i];
    //cout << i <<  " cand: " << x << endl;
    if (pt_int_tr(x, y, t)) {
      //cout << "   valid x: " << x << endl;
      min_x = min(min_x, x);
      max_x = max(max_x, x);
    }
  }
  min_x = max(min_x, -y);
  max_x = min(max_x, y);
  pair<ll, ll> ans = {min_x, max_x};
  clamp_mod(ans, y % 2);
  return ans;
}

ll f[N], f1[N];

ll powMod(ll x, ll pw) {
    if (pw == 0) return 1;
    ll tmp = powMod(x, pw / 2);
    if (pw % 2)
        return (x * tmp) % MOD * tmp % MOD;
    return tmp * tmp % MOD;
}

ll cnk(ll n, ll k) {
  if (n < k || k < 0) return 0;
    return (f[n] * f1[k] % MOD) * f1[n - k] % MOD;
}

void precalc() {
    f[0] = 1;
    f[1] = 1;
    for (int i = 2; i < N; ++i) {
        f[i] = (f[i - 1] * i) % MOD;
    }
    for (int i = 0; i < N; ++i) {
        f1[i] = powMod(f[i], MOD - 2);
    }
}

ll calc(vector<ll> bs) {
  vector<pair<ll, ll>> b;
  for (int i = 0; i <= MAX; ++i) {
    if (bs[i] != -1) {
      b.push_back({bs[i], i});
    }
  }  
  if (b.empty()) return 0;
  if (b[0] > b.back()) reverse(b.begin(), b.end());
  ll ans = 0;
  for (int r = 0; r <= MAX; ++r) {
    int i = lower_bound(b.begin(), b.end(), pair<ll, ll>(r, -INF)) - b.begin();
    if (i >= b.size()) continue;
    ll min_k = min(b[i].second, b.back().second);
    ll max_k = max(b[i].second, b.back().second);
    //assert(max_k + 1 >= r + 1);
    //assert(min_k >= r + 1);
    ans += (cnk(max_k + 1, r + 1) - cnk(min_k, r + 1));
    ans %= MOD;
    if (ans < 0) ans += MOD;
  }
  return ans;
}

void solve() {
  vector<Pt> triangle(3);
  vector<PtInt> t(3);
  for (int i = 0; i < 3; ++i) {
    cin >> t[i].x >> t[i].y;
    triangle[i].x = t[i].x;
    triangle[i].y = t[i].y;
  }

  vector<ll> r_borders(MAX + 1, -1);
  vector<ll> l_borders(MAX + 1, -1);

  vector<Line> lines(3);
  for (int i = 0; i < 3; ++i) {
    int j = (i + 1) % 3;
    lines[i] = Line(triangle[i], triangle[j]);
  }

  ll max_not_1 = -1;
  ll min_not_1 = -1;
  for (int i = 0; i <= MAX; ++i) {
    auto bs = get_borders(i, t, lines);
    if (bs.first > bs.second) {
      continue;
    }
    l_borders[i] = (i + bs.first) / 2 - 1;
    r_borders[i] = (i + bs.second) / 2;
    max_not_1 = i;
    if (min_not_1 == -1) min_not_1 = i;
    //cout << i << " " << l_borders[i] << " " << r_borders[i] << endl;
  }
  if (min_not_1 == -1) {
    cout << 0 << endl;
    return;
  }
  ll last_r = r_borders[min_not_1];
  for (int i = min_not_1 + 1; i < max_not_1; ++i) {
    if (r_borders[i] == -1) {
      l_borders[i] = r_borders[i] = last_r;
      //cout << i << " " << l_borders[i] << " " << r_borders[i] << endl;
    } else {
      last_r = r_borders[i];
    }
  }

  ll ans_r = calc(r_borders);
  ll ans_l = calc(l_borders);
  //cout << "ans_r: " << ans_r << " , ans_l: " << ans_l << endl;
  cout << (ans_r - ans_l + MOD) % MOD << endl;
}

int main() {
	ios_base::sync_with_stdio(false);
	cin.tie(0);
  precalc();
	int t = 1;
  cin >> t;
	while (t--) {
		solve();
	}
}
