#include <iostream>
#include <vector>
#include <set>
#include <algorithm>
#include <cmath>
#include <queue>

using namespace std;

typedef long long ll;

#define X first
#define Y second
#define all(v) (v).begin(), (v).end()
#define inb push_back

void merge_vectors(vector<int> &a, vector<int> &b, vector<int> &res) {
    int i = 0, j = 0;
    while (i < (int)a.size() && j < (int)b.size()) {
        while (j < (int)b.size() && b[j] <= a[i]) {
            res.inb(b[j]);
            ++j;
        }
        res.inb(a[i]);
        ++i;
    }
    for (; i < (int)a.size(); ++i) {
        res.inb(a[i]);
    }
    for (; j < (int)b.size(); ++j) {
        res.inb(b[j]);
    }
}

struct SegmentTree
{
    vector<vector<int>> t;
    SegmentTree() {};
    SegmentTree(int n) : t(vector<vector<int>>(4 * n)) {};
    void build(int v, int tl, int tr, vector<vector<int>> &a) {
        if (tl == tr) {
            t[v] = a[tl];
            return;
        }
        int tm = tl + tr >> 1;
        build(2 * v + 1, tl, tm, a);
        build(2 * v + 2, tm + 1, tr, a);
        merge_vectors(t[2 * v + 1], t[2 * v + 2], t[v]);
    }
    int get_eq(int v, int tl, int tr, int l, int r, int x) {
        if (tl > r || l > tr) {
            return 0;
        }
        if (l <= tl && tr <= r) {
            int l1 = lower_bound(all(t[v]), x) - t[v].begin();
            int res = t[v].size() - l1;
            return res;
        }
        int tm = tl + tr >> 1;
        return get_eq(2 * v + 1, tl, tm, l, r, x) + get_eq(2 * v + 2, tm + 1, tr, l, r, x);
    }
    int get(int v, int tl, int tr, int l, int r, int x) {
        if (tl > r || l > tr) {
            return 0;
        }
        if (l <= tl && tr <= r) {
            int l1 = upper_bound(all(t[v]), x) - t[v].begin();
            int res = t[v].size() - l1;
            return res;
        }
        int tm = tl + tr >> 1;
        return get(2 * v + 1, tl, tm, l, r, x) + get(2 * v + 2, tm + 1, tr, l, r, x);
    }
};

int solve() {
    int n;
    cin >> n;
    vector<vector<int>> g(n);
    vector<int> a(n);
    vector<int> p(n, -1);
    for (int i = 0; i < n; ++i) {
        int x, y, val;
        cin >> x >> y >> val;
        if (x) {
            g[i].inb(x - 1);
            p[x - 1] = i;
        }
        if (y) {
            g[i].inb(y - 1);
            p[y - 1] = i;
        }
        a[i] = val;
    }
    vector<pair<int, int>> segs(n);
    set<int> qxs;
    function<void(int)> dfs = [&](int u) {
        segs[u] = { a[u], a[u] };
        for (int to : g[u]) {
            dfs(to);
            segs[u].X = min(segs[u].X, segs[to].X);
            segs[u].Y = max(segs[u].Y, segs[to].Y);
        }
        qxs.insert(segs[u].X);
        qxs.insert(segs[u].Y);
    };
    dfs(0);
    vector<pair<int, int>> qq;
    int qc;
    cin >> qc;
    for (int i = 0; i < qc; ++i) {
        int l, r;
        cin >> l >> r;
        qxs.insert(l);
        qxs.insert(r);
        qq.inb({ l, r });
    }
    vector<int> xs;
    for (auto &x : qxs) {
        xs.inb(x);
    }
    // puts("ALL SEGS");
    vector<vector<int>> segs_to_push(xs.size());
    for (int i = 0; i < n; ++i) {
        if (p[i] == -1) {
            continue;
        }
        auto cur_seg = segs[p[i]];
        int l = lower_bound(all(xs), cur_seg.X) - xs.begin();
        int r = lower_bound(all(xs), cur_seg.Y) - xs.begin();
        // printf("%d %d\n", l, r);
        int cnt = 1;
        if (g[p[i]].size() == 1) {
            cnt = 2;
        }
        for (int it = 0; it < cnt; ++it) {
            segs_to_push[l].inb(r);
        }
    }
    for (int i = 0; i < (int)xs.size(); ++i) {
        if (segs_to_push[i].empty()) {
            continue;
        }
        sort(all(segs_to_push[i]));
    }
    int stn = xs.size();
    SegmentTree T(stn);
    T.build(0, 0, stn - 1, segs_to_push);
    for (auto &query : qq) {
        int l = lower_bound(all(xs), query.X) - xs.begin();
        int r = lower_bound(all(xs), query.Y) - xs.begin();
        // printf("CUR SEG :: %d %d\n", l, r);
        int res1 = T.get_eq(0, 0, stn - 1, 0, l - 1, l);
        int res2 = T.get(0, 0, stn - 1, l, r, r);
        // printf("RES :: %d // %d %d\n", res1 + res2 + 1, res1, res2);
        printf("%d\n", res1 + res2 + 1);
    }
    return 0;
}

int main() {
	ios_base::sync_with_stdio(0);
	cin.tie();
	solve();
	return 0;
}